.. geneflow documentation

GeneFlow Documentation
======================

Version: 2.4.1

GeneFlow (GF) is a light-weight platform-agnostic workflow engine for scientific computing.

.. toctree::
   :maxdepth: 3

   chapters/background
   chapters/install
   chapters/usage
   chapters/definition
   chapters/apps
   chapters/tutorials

